@@ -41,9 +41,7 @@ const MIN_FREQUENT_APPS_COUNT = 3;
 const INDICATORS_BASE_TIME = 0.25;
 const INDICATORS_ANIMATION_DELAY = 0.125;
 const INDICATORS_ANIMATION_MAX_TIME = 0.75;
-// Fraction of page height the finger or mouse must reach
-// to change page
-const PAGE_SWITCH_TRESHOLD = 0.2;
+
 const PAGE_SWITCH_TIME = 0.3;
 
 const VIEWS_SWITCH_TIME = 0.4;
@@ -81,6 +79,10 @@ function _getFolderName(folder) {
     return name;
 }
 
+function clamp(value, min, max) {
+    return Math.max(min, Math.min(max, value));
+}
+
 const BaseAppView = new Lang.Class({
     Name: 'BaseAppView',
     Abstract: true,
@@ -439,8 +441,8 @@ const AllView = new Lang.Class({
     },
 
     goToPage: function(pageNumber) {
-        if(pageNumber < 0 || pageNumber > this._grid.nPages() - 1)
-            return;
+        pageNumber = clamp(pageNumber, 0, this._grid.nPages() - 1);
+
         if (this._currentPage == pageNumber && this._displayingPopup && this._currentPopup)
             return;
         if (this._displayingPopup && this._currentPopup)
@@ -472,14 +474,12 @@ const AllView = new Lang.Class({
         // longer than PAGE_SWITCH_TIME
         time = Math.min(time, PAGE_SWITCH_TIME);
 
-        if (pageNumber < this._grid.nPages() && pageNumber >= 0) {
-            this._currentPage = pageNumber;
-            Tweener.addTween(this._adjustment,
-                             { value: this._grid.getPageY(this._currentPage),
-                               time: time,
-                               transition: 'easeOutQuad' });
-            this._pageIndicators.setCurrentPage(pageNumber);
-        }
+        this._currentPage = pageNumber;
+        Tweener.addTween(this._adjustment,
+                         { value: this._grid.getPageY(this._currentPage),
+                           time: time,
+                           transition: 'easeOutQuad' });
+        this._pageIndicators.setCurrentPage(pageNumber);
     },
 
     _diffToPage: function (pageNumber) {
@@ -526,15 +526,19 @@ const AllView = new Lang.Class({
     _onPanEnd: function(action) {
          if (this._displayingPopup)
             return;
-        let diffCurrentPage = this._diffToPage(this._currentPage);
-        if (diffCurrentPage > this._scrollView.height * PAGE_SWITCH_TRESHOLD) {
-            if (action.get_velocity(0)[2] > 0)
-                this.goToPage(this._currentPage - 1);
-            else
-                this.goToPage(this._currentPage + 1);
-        } else {
-            this.goToPage(this._currentPage);
-        }
+
+        let pageHeight = this._grid.getPageHeight();
+
+        // Calculate the scroll value we'd be at, which is our current
+        // scroll plus any velocity the user had when they released
+        // their finger.
+
+        let velocity = -action.get_velocity(0)[2];
+        let endPanValue = this._adjustment.value + velocity;
+
+        let closestPage = Math.round(endPanValue / pageHeight);
+        this.goToPage(closestPage);
+
         this._panning = false;
     },
 
@@ -764,7 +768,7 @@ const AppDisplay = new Lang.Class({
         this._viewStack = new St.Widget({ x_expand: true, y_expand: true,
                                           layout_manager: this._viewStackLayout });
         this._viewStackLayout.connect('allocated-size-changed', Lang.bind(this, this._onAllocatedSizeChanged));
-        this.actor.add_actor(this._viewStack, { expand: true });
+        this.actor.add_actor(this._viewStack);
         let layout = new ControlsBoxLayout({ homogeneous: true });
         this._controls = new St.Widget({ style_class: 'app-view-controls',
                                          layout_manager: layout });
@@ -1402,6 +1406,7 @@ const AppIcon = new Lang.Class({
                     this.popupMenu();
                     return GLib.SOURCE_REMOVE;
                 }));
+            GLib.Source.set_name_by_id(this._menuTimeoutId, '[gnome-shell] this.popupMenu');
         } else if (button == 3) {
             this.popupMenu();
             return Clutter.EVENT_STOP;
@@ -1597,6 +1602,26 @@ const AppIconMenu = new Lang.Class({
                     favs.addFavorite(this._source.app.get_id());
                 }));
             }
+
+            if (Shell.AppSystem.get_default().lookup_app('org.gnome.Software.desktop')) {
+                this._appendSeparator();
+                let item = this._appendMenuItem(_("Show Details"));
+                item.connect('activate', Lang.bind(this, function() {
+                    let id = this._source.app.get_id();
+                    let args = GLib.Variant.new('(ss)', [id, '']);
+                    Gio.DBus.get(Gio.BusType.SESSION, null,
+                        function(o, res) {
+                            let bus = Gio.DBus.get_finish(res);
+                            bus.call('org.gnome.Software',
+                                     '/org/gnome/Software',
+                                     'org.gtk.Actions', 'Activate',
+                                     GLib.Variant.new('(sava{sv})',
+                                                      ['details', [args], null]),
+                                     null, 0, -1, null, null);
+                            Main.overview.hide();
+                        });
+                }));
+            }
         }
     },
 
