@@ -266,12 +266,14 @@ const Keyboard = new Lang.Class({
             return;
         }
 
-        if (!this._showIdleId)
-            this._showIdleId = GLib.idle_add(GLib.PRIORITY_DEFAULT_IDLE,
-                                             Lang.bind(this, function() {
-                                                 this.Show(time);
-                                                 return GLib.SOURCE_REMOVE;
-                                             }));
+        if (!this._showIdleId) {
+          this._showIdleId = GLib.idle_add(GLib.PRIORITY_DEFAULT_IDLE,
+                                           Lang.bind(this, function() {
+                                               this.Show(time);
+                                               return GLib.SOURCE_REMOVE;
+                                           }));
+          GLib.Source.set_name_by_id(this._showIdleId, '[gnome-shell] this.Show');
+        }
     },
 
     _createLayersForGroup: function (gname) {
@@ -500,6 +502,7 @@ const Keyboard = new Lang.Class({
                                                        this._show(monitor);
                                                        return GLib.SOURCE_REMOVE;
                                                    }));
+        GLib.Source.set_name_by_id(this._keyboardRestingId, '[gnome-shell] this._clearKeyboardRestTimer');
     },
 
     _show: function(monitor) {
@@ -526,6 +529,7 @@ const Keyboard = new Lang.Class({
                                                        this._hide();
                                                        return GLib.SOURCE_REMOVE;
                                                    }));
+        GLib.Source.set_name_by_id(this._keyboardRestingId, '[gnome-shell] this._clearKeyboardRestTimer');
     },
 
     _hide: function() {
