@@ -9,7 +9,6 @@ const Mainloop = imports.mainloop;
 const Meta = imports.gi.Meta;
 const Shell = imports.gi.Shell;
 const St = imports.gi.St;
-const GSystem = imports.gi.GSystem;
 
 const Components = imports.ui.components;
 const CtrlAltTab = imports.ui.ctrlAltTab;
@@ -213,7 +212,12 @@ function _initializeUI() {
                               if (screenShield) {
                                   screenShield.lockIfWasLocked();
                               }
-                              if (LoginManager.haveSystemd() && sessionMode.currentMode === 'user') {
+                              if (LoginManager.haveSystemd() &&
+                                  sessionMode.currentMode != 'gdm' &&
+                                  sessionMode.currentMode != 'initial-setup') {
+                                  // Do not import globally to not depend
+                                  // on systemd on non-systemd systems.
+                                  let GSystem = imports.gi.GSystem;
                                   GSystem.log_structured_print('GNOME Shell started at ' + _startDate,
                                                                ['MESSAGE_ID=' + GNOMESHELL_STARTED_MESSAGE_ID]);
                               } else {
